@@ -1,7 +1,7 @@
 from __future__ import annotations
 from abc import ABC
 from typing import Iterable
-from psyki.ski import Formula
+from psyki.logic import Formula
 import psyki.logic.datalog as datalog
 
 
@@ -46,7 +46,7 @@ def optimize_datalog_formula(formula: Formula):
 
 class DatalogFormula(Formula):
 
-    def __init__(self, lhs: DefinitionClause, rhs: Clause, op: str):
+    def __init__(self, lhs: DefinitionClause, rhs: Clause, op: str = '←'):
         self.lhs: DefinitionClause = lhs
         self.rhs: Clause = rhs
         self.op: str = op
@@ -158,6 +158,22 @@ class Predication(Constant):
         return Predication(self.name)
 
 
+class Boolean(Constant):
+
+    def __init__(self, value: bool = True):
+        self.value: bool = value
+
+    def __str__(self) -> str:
+        return str(self.value)
+
+    @property
+    def is_true(self) -> bool:
+        return self.value
+
+    def copy(self) -> Formula:
+        return Boolean(self.value)
+
+
 class Number(Constant):
 
     def __init__(self, value: str):
