@@ -1,9 +1,10 @@
 from os.path import isdir
+from psyki.logic.datalog.grammar import DatalogFormula, Expression, DefinitionClause, Argument, Negation, Unary, Nary, \
+    Variable, Number, Predication
 from psyki.resources import PATH, create_antlr4_parser
 if not isdir(str(PATH / 'dist')):
     create_antlr4_parser(str(PATH / 'Datalog.g4'), str(PATH / 'dist'))
 from antlr4 import CommonTokenStream, InputStream
-from psyki.logic.datalog import *
 from psyki.resources.dist.DatalogLexer import DatalogLexer
 from psyki.resources.dist.DatalogParser import DatalogParser
 
@@ -16,6 +17,34 @@ def get_formula(ast: DatalogParser.FormulaContext) -> DatalogFormula:
     return DatalogFormula(_get_definition_clause(ast.lhs), _get_clause(ast.rhs), ast.op.text)
 
 
+def to_prolog_string(rule: DatalogFormula) -> str:
+    # TODO: for now it works with just propositional rules without clauses except 'class'.
+    op_mapping = {
+        '≤': '=<',
+        '<': '<',
+        '≥': '>',
+        '>': '>',
+        '∧': ',',  # should not be necessary
+        '=': '=',
+    }
+
+    def unfold_body(e: Expression, result=[]) -> list[str]:
+        if isinstance(e.lhs, Expression):
+            result = result + unfold_body(e.lhs)
+        if isinstance(e.rhs, Expression):
+            result = result + unfold_body(e.rhs)
+        if not isinstance(e.lhs, Expression) and not isinstance(e.rhs, Expression):
+            return ['\'' + op_mapping[e.op] + '\'(' + str(e.lhs) + ', ' + str(e.rhs) + ')']
+        return result
+
+    head = str(rule.lhs)
+    if isinstance(rule.rhs, Expression):
+        body = ', '.join(unfold_body(rule.rhs))
+        return head + ' :- ' + body + '.'
+    else:
+        return head + '.'
+
+
 def _get_definition_clause(node: DatalogParser.DefPredicateArgsContext):
     return DefinitionClause(node.pred.text, _get_arguments(node.args))
 
@@ -27,9 +56,10 @@ def _get_arguments(node: DatalogParser.MoreArgsContext or DatalogParser.LastTerm
         return Argument(_get_term(node.name))
 
 
-def _get_clause(node: DatalogParser.ClauseExpressionContext or DatalogParser.ClauseExpressionNoParContext or
-                      DatalogParser.ClauseLiteralContext or DatalogParser.ClauseClauseContext):
-    if isinstance(node, DatalogParser.ClauseExpressionContext) or isinstance(node, DatalogParser.ClauseExpressionNoParContext):
+def _get_clause(node: DatalogParser.ClauseExpressionContext or DatalogParser.ClauseExpressionNoParContext
+                      or DatalogParser.ClauseLiteralContext or DatalogParser.ClauseClauseContext):
+    if isinstance(node, DatalogParser.ClauseExpressionContext)\
+            or isinstance(node, DatalogParser.ClauseExpressionNoParContext):
         return Expression(_get_clause(node.left), _get_clause(node.right), node.op.text)
     elif isinstance(node, DatalogParser.ClauseLiteralContext):
         return _get_literal(node.lit)
@@ -44,8 +74,8 @@ def _get_literal(node: DatalogParser.LiteralPredContext or DatalogParser.Literal
         return _get_predicate(node.pred)
 
 
-def _get_predicate(
-        node: DatalogParser.PredicateTermContext or DatalogParser.PredicateUnaryContext or DatalogParser.PredicateArgsContext):
+def _get_predicate(node: DatalogParser.PredicateTermContext or DatalogParser.PredicateUnaryContext
+                         or DatalogParser.PredicateArgsContext):
     if isinstance(node, DatalogParser.PredicateTermContext):
         return _get_term(node.name)
     elif isinstance(node, DatalogParser.PredicateUnaryContext):
